@@ -138,6 +138,9 @@ impl MutTopic {
     }
 }
 
+unsafe impl Send for EventBus {}
+unsafe impl Sync for EventBus {}
+
 /// Unmutable subscriber trait
 /// # Example
 ///
